# -*- coding: utf-8 -*-
import json
import random

import cv2
import yaml

random.seed(42)


def assign_random_split(train_prob, val_prob):
    """
    assuming train_prob + valid_prob + test_prob = 1
    """
    prob = random.random()
    if prob <= train_prob:
        return "train"
    elif prob <= train_prob + val_prob:
        return "valid"
    else:
        return "test"


def save_text(path, text):
    with open(path, "w") as f:
        f.write(text)


def save_image(path, image):
    cv2.imwrite(path, cv2.cvtColor(image, cv2.COLOR_BGR2RGB))


def save_json(path, dict):
    with open(path, "w") as outfile:
        json.dump(dict, outfile, indent=4)


def insert_token(text, count, start_token, end_token, offset, length):
    text = (
        # Text before entity
        text[: count + offset]
        # Starting token
        + start_token
        # Entity
        + text[count + offset : count + 1 + offset + length]
        # End token
        + end_token
        # Text after entity
        + text[count + 1 + offset + length :]
    )
    return text, count + 2


def parse_tokens(filename):
    with open(filename) as f:
        return yaml.safe_load(f)
